Struct diem_data_client::diemnet::DiemNetDataClient[][src]

pub struct DiemNetDataClient { /* fields omitted */ }
A DiemDataClient that fulfills requests from remote peers’ Storage Service over DiemNet.

The DiemNetDataClient:

  1. Sends requests to connected DiemNet peers.
  2. Does basic type conversions and error handling on the responses.
  3. Routes requests to peers that advertise availability for that data.
  4. Maintains peer scores based on each peer’s observed quality of service and upper client reports of invalid or malicious data.
  5. Selects high quality peers to send each request to.
  6. Exposes a condensed data summary of our peers’ data advertisements.

The client currently assumes 1-request => 1-response. Streaming responses are handled at an upper layer.

The client is expected to be cloneable and usable from many concurrent tasks and/or threads.

Implementations