Struct diem_data_client::diemnet::DiemNetDataClient [−][src]
pub struct DiemNetDataClient { /* fields omitted */ }Expand description
A DiemDataClient that fulfills requests from remote peers’ Storage Service
over DiemNet.
The DiemNetDataClient:
- Sends requests to connected DiemNet peers.
- Does basic type conversions and error handling on the responses.
- Routes requests to peers that advertise availability for that data.
- Maintains peer scores based on each peer’s observed quality of service and upper client reports of invalid or malicious data.
- Selects high quality peers to send each request to.
- Exposes a condensed data summary of our peers’ data advertisements.
The client currently assumes 1-request => 1-response. Streaming responses are handled at an upper layer.
The client is expected to be cloneable and usable from many concurrent tasks and/or threads.
Implementations
pub fn new(
data_client_config: DiemDataClientConfig,
storage_service_config: StorageServiceConfig,
time_service: TimeService,
network_client: StorageServiceClient
) -> (Self, DataSummaryPoller)